@@ -1,5 +1,5 @@
 package Email::Archive::Storage;
-use Moose::Role;
+use Moo::Role;
 
 requires qw/store retrieve search storage_connect/;
 1;
